@@ -6,7 +6,7 @@ Toadfarm - One Mojolicious app to rule them all
 
 =head1 VERSION
 
-0.52
+0.53
 
 =head1 DESCRIPTION
 
@@ -56,8 +56,18 @@ See L<Toadfarm::Manual::DSL> for more information about the different functions.
     level    => "info",
   };
 
-  mount "MyApp"        => {"Host" => "myapp.example.com"};
-  mount "/path/to/app" => {"Host" => "example.com", mount_point => "/other"};
+  mount "MyApp"  => {
+    Host   => "myapp.example.com",
+    config => {
+      config_parameter_for_myapp => "foo"
+    },
+  };
+
+  mount "/path/to/app" => {
+    Host        => "example.com",
+    mount_point => "/other",
+  };
+
   mount "Catch::All::App";
 
   plugin "Toadfarm::Plugin::AccessLog";
@@ -73,6 +83,8 @@ start/stop actions.
   $ /etc/init.d/your-script start
   $ /etc/init.d/your-script stop
 
+See also L<Toadfarm::Manual::RunningToadfarm/Init script> for more details.
+
 You can also start the application with normal L<Mojolicious> commands:
 
   $ morbo /etc/init.d/your-script
@@ -102,10 +114,35 @@ You can also start the application with normal L<Mojolicious> commands:
 
 =item * L<Toadfarm::Plugin::AccessLog>
 
+Log each request that hit your application.
+
 =item * L<Toadfarm::Plugin::Reload>
 
+Reload Hypnotoad with a L<GitHub push hook|https://help.github.com/articles/about-webhooks/>.
+
+=item * L<Mojolicious::Plugin::SizeLimit>
+
+Kill Hypnotoad workers if they grow too large.
+
 =back
 
+=head1 PREVIOUS VERSIONS
+
+L<Toadfarm> prior to version 0.49 used to be a configuration file loaded in
+by the C<toadfarm> script. This resulted in all the executables to be named
+C<toadfarm> instead of something descriptive. It also felt a bit awkward to
+take over C<MOJO_CONFIG> and use all the crazy hacks to start C<hypnotoad>.
+
+It also didn't work well as an init script, so there still had to be a
+seperate solution for that.
+
+The new L<Toadfarm> DSL aim to solve all of these issues. This means that
+if you decide to still use any C<MOJO_CONFIG>, it should be for the
+applications loaded from inside C<Toadfarm> and not the startup script.
+
+Note that the old solution still works, but a warning tells you to change
+to the new L<DSL|Toadfarm::Manual::DSL> based API.
+
 =cut
 
 use Mojo::Base 'Mojolicious';
@@ -116,7 +153,7 @@ use File::Spec;
 use File::Which;
 use constant DEBUG => $ENV{TOADFARM_DEBUG} ? 1 : 0;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 BEGIN {
   $ENV{TOADFARM_ACTION} //= $ENV{MOJO_APP_LOADER} ? 'load' : (@ARGV and $ARGV[0] =~ /^(reload|start|stop)$/) ? $1 : '';
@@ -124,16 +161,17 @@ BEGIN {
 }
 
 sub import {
-  return unless grep {/^(-dsl|-init)/} @_;
+  return unless grep {/^(-dsl|-init|-test)/} @_;
 
   my $class  = shift;
   my $caller = caller;
   my $app    = Toadfarm->new;
+  my $action = $ENV{TOADFARM_ACTION};
   my %got;
 
+  $action = 'load' if grep {/^-test/} @_ or $ENV{TOADFARM_ACTION} eq 'test';
   $_->import for qw(strict warnings utf8);
   feature->import(':5.10');
-
   unshift @{$app->commands->namespaces}, 'Toadfarm::Command';
 
   monkey_patch $caller, (
@@ -152,7 +190,8 @@ sub import {
 
       $app->moniker($class->_moniker) if $app->moniker eq 'toadfarm';
       $app->config->{hypnotoad}{pid_file} ||= $class->_pid_file($app);
-      $app = $class->_setup_app($app, \%got) if $ENV{TOADFARM_ACTION} eq 'load';
+      $app = $class->_setup_app($app, \%got) if $action eq 'load';
+      Mojo::UserAgent::Server->app($app);
       warn '$config=' . Mojo::Util::dumper($app->config) if DEBUG;
       $app->start;
     },
@@ -206,7 +245,17 @@ sub _mount_apps {
     my $server      = Mojo::Server->new;
     my $path        = $name;
     my $mount_point = delete $rules->{mount_point};
-    my ($app, $request_base, @over, @error);
+    my ($app, $request_base, $tmp, @over, @error);
+
+    local $ENV{MOJO_CONFIG} = $ENV{MOJO_CONFIG};
+
+    if (ref $rules->{config} eq 'HASH') {
+      require File::Temp;
+      my %config = (%{$self->config}, %{$rules->{config}});
+      $tmp = File::Temp->new;
+      Mojo::Util::spurt(Mojo::Util::dumper(\%config), $tmp->filename);
+      $ENV{MOJO_CONFIG} = $tmp->filename;
+    }
 
     $path = File::Which::which($path) || class_to_path($path) unless -r $path;
     $app ||= eval { $server->load_app($path) }  or push @error, $@;
